// Adrian Budau
// 100 pct

#include <cmath>

#include <iostream>
#include <vector>
#include <algorithm>
#include <limits>
#include <fstream>

using namespace std;

const double kEpsilon = 1e-6;

int sign(const double &a) {
    if (a + kEpsilon < 0)
        return -1;
    if (a - kEpsilon > 0)
        return 1;
    return 0;
}

pair<double, double> rotate(pair<double, double> &point, const pair<double, double> &eps) {
    return make_pair(point.first * eps.first - point.second * eps.second, point.second * eps.first + point.first * eps.second);
}

double minX, minY, maxX, maxY;
double check(vector< pair<double, double> > P, const pair<double, double> eps) {
    minX = minY = numeric_limits<double>::max();
    maxX = maxY = numeric_limits<double>::min();

    for (int i = 0; i < int(P.size()); ++i) {
        pair<double, double> V = rotate(P[i], eps);

        if (V.first < minX)
            minX = V.first;
        if (V.first > maxX)
            maxX = V.first;
        if (V.second < minY)
            minY = V.second;
        if (V.second > maxY)
            maxY = V.second;
    }

    return (maxX - minX) - (maxY - minY);
}

int main() {
    ifstream cin("tarc.in");
    ofstream cout("tarc.out");

    int T; cin >> T;
    for (int i = 1; i <= T; ++i) {
        int N; cin >> N;

        vector< pair<double, double> > P(N);
        for (int i = 0; i < N; ++i) {
            int x, y; cin >> x >> y;
            P[i] = make_pair<double, double>(x, y);
        }

        double left = 0, right = M_PI / 2;
        double cleft = check(P, make_pair(cos(left), sin(left)));
        for (int stp = 0; stp <= 80 && sign(cleft); ++stp) {
            double mid = (left + right) / 2;
            double cmid = check(P, make_pair(cos(mid), sin(mid)));
            if (sign(cmid) == 0) {
                left = mid;
                break;
            }

            if (sign(cmid) == sign(cleft))
                left = mid;
            else
                right = mid;
        }

        pair<double, double> A(minX, minY), B(minX, maxY), C(maxX, maxY), D(maxX, minY);
        pair<double, double> eps = make_pair(cos(-left), sin(-left));
        A = rotate(A, eps);
        B = rotate(B, eps);
        C = rotate(C, eps);
        D = rotate(D, eps);

        cout.setf(ios::fixed, ios::floatfield);
        cout.precision(9);

        cout << A.first << " " << A.second << "\n";
        cout << B.first << " " << B.second << "\n";
        cout << C.first << " " << C.second << "\n";
        cout << D.first << " " << D.second << "\n";
    }
}
